CHANGELOG
=========

This project uses `semantic versioning <http://semver.org/>`_.
This change log uses principles from `keep a changelog <http://keepachangelog.com/>`_.

[Unreleased]
------------

Added
^^^^^

- ``dtool_lookup_api.lookup``
- ``dtool_lookup_api.search``
- ``dtool_lookup_api.query``
- ``dtool_lookup_api.config``
- ... as well as their asynchronous pendants within ``dtool_lookup_api.asynchronous`` ...
- and the underlying core mechanisms within ``dtool_lookup_api.core.LookupClient```.


Changed
^^^^^^^


Deprecated
^^^^^^^^^^


Removed
^^^^^^^


Fixed
^^^^^


Security
^^^^^^^^
